# Release notes for MUSE v1.4.1 (May 9, 2025)

These are the main changes in MUSE v1.4.1.

## Fixed a bug affecting technologies with zero existing capacity ({github}`703`)

- There was a small bug introduced in v1.4.0 that meant that commodity demands were failing to be recognised in some subsectors containing technologies with zero existing capacity
- See {github}`703` for more details

## Fixed a bug with outputs cache feature ({github}`704`)
